@@ -12,7 +12,7 @@ use feature ();
 package MooX::Pression;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.011';
+our $VERSION   = '0.012';
 
 use Keyword::Declare;
 use B::Hooks::EndOfScope;
@@ -44,13 +44,15 @@ BEGIN {
 		}
 		elsif ($action eq -go) {
 			if ($gather{$me}{$caller}{'_defer_role'}) {
-				die 'nested roles not currently supported';
+				require Carp;
+				Carp::croak('Nested roles are not supported');
 			}
 			if ($gather{$me}{$caller}{'_defer_role_generator'}) {
-				die 'nested role generators not currently supported';
+				require Carp;
+				Carp::croak('Nested role generators are not supported');
 			}
 			if ($gather{$me}{$caller}{'_defer_class_generator'}) {
-				die 'nested class generators not currently supported';
+				$me->_undefer_class_generators($gather{$me}{$caller}{'class_generator'}||=[], delete $gather{$me}{$caller}{'_defer_class_generator'});
 			}
 			if ($gather{$me}{$caller}{'_defer_class'}) {
 				$me->_undefer_classes($gather{$me}{$caller}{'class'}, delete $gather{$me}{$caller}{'_defer_class'});
@@ -76,7 +78,7 @@ BEGIN {
 	}
 	sub _undefer_classes {
 		my ($me, $classes, $d) = @_;
-		my %class_hash = @$classes;
+		my %class_hash = @{$classes||[]};
 		my @deferred;
 		my $max_depth = 0;
 		while (@$d) {
@@ -91,6 +93,15 @@ BEGIN {
 				next SPEC unless $spec->{_depth} == $depth;
 				my $parent_key = join('|', @{$spec->{_stack}});
 				my $my_key     = join('|', @{$spec->{_stack}}, $spec->{_class_name});
+				if (not $class_hash{$parent_key}) {
+					require Carp;
+					Carp::croak(sprintf(
+						'%s is nested in %s but %s is not a class',
+						$spec->{_class_name},
+						$spec->{_stack}[-1],
+						$spec->{_stack}[-1],
+					));
+				}
 				push @{ $class_hash{$parent_key}{subclass} ||=[] }, $spec->{_class_name}, $spec;
 				$class_hash{$my_key} = $spec;
 			}
@@ -101,7 +112,22 @@ BEGIN {
 			delete $spec->{_depth};
 		}
 	}
-	
+	sub _undefer_class_generators {
+		my ($me, $classes, $d) = @_;
+		while (@$d) {
+			my ($class, $spec) = splice(@$d, 0, 2);
+			my $extends = $spec->{_stack}[-1];
+			my $next = delete($spec->{code});
+			$spec->{code} = sub {
+				my $got = $next->(@_);
+				$got->{extends} ||= [$extends];
+				$got;
+			};
+			delete $spec->{_stack};
+			push @$classes, $class, $spec;
+		}
+	}
+
 	$INC{'MooX/Pression/_Gather.pm'} = __FILE__;
 };
 
@@ -895,7 +921,7 @@ sub _modifier {
 #{
 #	package MooX::Pression::Anonymous::Package;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.011';
+#	our $VERSION   = '0.012';
 #	use overload q[""] => sub { ${$_[0]} }, fallback => 1;
 #	sub DESTROY {}
 #	sub AUTOLOAD {
@@ -906,7 +932,7 @@ sub _modifier {
 #	
 #	package MooX::Pression::Anonymous::Class;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.011';
+#	our $VERSION   = '0.012';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	sub new {
 #		my $me = shift;
@@ -919,12 +945,12 @@ sub _modifier {
 #	
 #	package MooX::Pression::Anonymous::Role;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.011';
+#	our $VERSION   = '0.012';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	
 #	package MooX::Pression::Anonymous::ParameterizableClass;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.011';
+#	our $VERSION   = '0.012';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -938,7 +964,7 @@ sub _modifier {
 #
 #	package MooX::Pression::Anonymous::ParameterizableRole;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.011';
+#	our $VERSION   = '0.012';
 #	our @ISA       = qw(MooX::Pression::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -1523,11 +1549,10 @@ values. For example:
       default      => 0,
       handles_via  => 'Counter',
       handles      => {
-        get_older => 'inc',   # increment age
+        birthday => 'inc',   # increment age
       },
     );
-    method birthday () {
-      $self->get_older;
+    after birthday {
       if ($self->age < 30) {
         say "yay!";
       }
@@ -2121,6 +2146,71 @@ If C<class> definitions are nested, C<authority> will be inherited by
 child classes. If a parent class is specified via C<extends>, C<authority>
 will not be inherited.
 
+=head2 Helper Subs
+
+Earlier it was stated that C<sub> cannot be used to define methods in
+classes and roles. This is true, but that doesn't mean that it has no
+use.
+
+  package MyApp {
+    use MooX::Pression;
+    
+    sub helper_function { ... }
+    
+    class Foo {
+      method foo {
+        ...;
+        helper_function(...);
+        ...;
+      }
+    }
+    
+    class Bar {
+      sub other_helper { ... }
+      method bar {
+        ...;
+        helper_function(...);
+        other_helper(...);
+        ...;
+      }
+    }
+  }
+
+The subs defined by C<sub> end up in the "MyApp" package, not
+"MyApp::Foo" or "MyApp::Bar". They can be called by any of the classes
+and roles defined in MyApp. This makes them suitable for helper subs
+like logging, L<List::Util>/L<Scalar::Util> sorts of functions, and
+so on.
+
+  package MyApp {
+    use MooX::Pression;
+    
+    use List::Util qw( any all first reduce );
+    # the above functions are now available within
+    # all of MyApp's classes and roles, but won't
+    # pollute any of their namespaces.
+    
+    use namespace::clean;
+    # And now they won't even pollute MyApp's namespace.
+    # Though I'm pretty sure this will also stop them
+    # from working in any methods that used ":optimize".
+    
+    class Foo { ... } 
+    role Bar { ... } 
+    role Baz { ... } 
+  }
+
+C<sub> is also usually your best option for those tiny little
+coderefs that need to be defined here and there:
+
+  has foo (
+    is       => lazy,
+    type     => ArrayRef[Str],
+    builder  => sub {  []  },
+  );
+
+Though consider using L<Sub::Quote> if you're using Moo.
+
 =head2 Utilities
 
 MooX::Pression also exports constants C<true> and C<false> into your
@@ -2259,9 +2349,29 @@ B<SpeciesClass> and B<SpeciesInstance> type constraints.
   is_SpeciesInstance( $lassie );      # true
   is_SpeciesClass( ref($lassie) );    # true
 
-Subclasses cannot be nested inside parameterizable classes.
-It should theoretically be possible to nest parameterizable classes
-within regular classes, but this isn't implemented yet.
+Subclasses cannot be nested inside parameterizable classes, but
+parameterizable classes can be nested inside regular classes, in
+which case the classes they generate will inherit from the outer
+class.
+
+  package MyApp {
+    use MooX::Pression;
+    
+    class Animal {
+      has name;
+      class Species ( Str $common_name, Str $binomial ) {
+        constant common_name  = $common_name;
+        constant binomial     = $binomial;
+      }
+    }
+    
+    class Dog {
+      extends Species('dog', 'Canis familiaris');
+      method bark () {
+        say "woof!";
+      }
+    }
+  }
 
 Anonymous parameterizable classes are possible:
 
